@@ -45,6 +45,7 @@ class Util(object):
 
         if encoding:
             out = out.decode(encoding)
+            err = err.decode(encoding)
 
         try:
             logging.debug('out[: 100]: {}'.format(out[: 100].strip()))
@@ -95,8 +96,7 @@ class Util(object):
         if self.sn.count('.') != 3:
             return  # 非网络设备不处理
         self.cmd('adb disconnect {}'.format(self.sn))  # 首先断开连接，排除该 sn 当前是 offline 状态
-        out, err = self.cmd('adb connect {}'.format(self.sn))
-        return 'connected to' in out
+        self.cmd('adb connect {}'.format(self.sn))
 
     def get_first_sn(self):
         sn_info = self.get_sn_info()
